<template>
  <ReactionIcon :reaction-list="reactions"/>
  <div v-if="is_forwarded === 1"
        class="absolute  -top-8 gap-1 rounded-tl-xl rounded-tr-xl left-0 block w-full  ">
    <div class="relative flex py-2 items-center">
      <svg xmlns="http://www.w3.org/2000/svg" class="w-5 h-5 fill-current text-gray-400"
            viewBox="0 0 24 24">
        <path d="M21,12L14,5V9C7,10 4,15 3,20C5.5,16.5 9,14.9 14,14.9V19L21,12Z"/>
      </svg>
      <span class="italic text-gray-400">Forwarded</span>
    </div>
  </div>
  <div v-if="reply_from_id && object?.replied_message"
        class="relative rounded-lg p-2 w-full block bg-scheme-primary bg-opacity-10 mb-2">
    <span class="block">{{ object?.replied_message?.name }}</span>
    <span
        v-html="helpers.whatsappFormatting(helpers.urlify(helpers.decodeMessage(object?.replied_message?.message)))"></span>
  </div>
  <div
      class="relative flex gap-3 justify-between items-center mb-4 rounded-md p-3 overflow-hidden text-base whitespace-normal text-gray-800"
      style="background: rgba(0, 0, 0, .1)">

    <div v-if="object.contact.name" class="flex gap-3 flex-grow relative">
      <div class="relative block w-auto">
        <Avatar/>
      </div>
      <div class="w-full">
        <h3 class="font-semibold block text-sm">{{ object.contact.name }}</h3>
        <h4 class="font-medium block text-sm">{{ object.contact.phone }}</h4>
      </div>
      <div class="flex items-start">
        <button @click="copyContact" class="btn btn-circle btn-ghost btn-sm p-1">
          <svg xmlns="http://www.w3.org/2000/svg" class="fill-current text-scheme-primary" viewBox="0 0 24 24">
            <path
                d="M19,21H8V7H19M19,5H8A2,2 0 0,0 6,7V21A2,2 0 0,0 8,23H19A2,2 0 0,0 21,21V7A2,2 0 0,0 19,5M16,1H4A2,2 0 0,0 2,3V17H4V3H16V1Z"/>
          </svg>
        </button>
      </div>
    </div>
  </div>
      <div v-if="isFromApplication && isSeller" class="flex items-center gap-2 whitespace-nowrap  rounded-full py-1 px-2 bottom-1 text-xs bg-white text-primary text-right select-none">
        <span class="w-2 h-2 bg-scheme-primary rounded-full"></span>
        <span>{{ applicationAgentName }}</span>
      </div>
      <div v-else-if="assignee"
            class="flex items-center gap-2 whitespace-nowrap  rounded-full py-1 px-2 bottom-1 text-xs bg-white text-primary text-right select-none">
        <span class="w-2 h-2 bg-scheme-primary rounded-full"></span>
        <span>{{ assignee.full_name }}</span>
      </div>
  <div class="flex gap-1 items-center justify-end">
    <span class="block  text-xs text-gray-600 text-right select-none">{{ date }}</span>
    <!-- loading -->
    <template v-if="isSeller && !isLoader">
      <IcMessageStatus :status="status"/>
    </template>
  </div>
  <div class="relative block w-full border-t border-gray-300 mt-2 pt-2">
    <button @click.prevent="importContact" class="btn btn-block btn-ghost normal-case text-primary">Import Kontak</button>
  </div>
</template>

<script setup lang="ts">

import {ref} from "vue";
import IcPersonGeneral from "../Icon/IcPersonGeneral.vue";
import helpers from "../../utils/helpers";
import IcMessageStatus from "../Icon/IcMessageStatus.vue";
import Avatar from "../Avatar/Avatar.vue";
import {message} from "ant-design-vue";
import ReactionIcon from "../Icon/ReactionIcon.vue";
import ChatRepliedMessage from "./ChatRepliedMessage.vue";
import {useDashboardStore} from "../../stores/dashboard";

interface Props {
  isSeller?: boolean
  isLoader?: boolean
  is_forwarded?: number
  date?: string
  status?: string
  message?: string
  wa_error_message?: string
  reply_from_id?: any
  chatType?: string
  assignee?: {
    full_name?: string
  }
  reactions?: any
  object?: {
    contact?: {
      name?: string,
      phone?: string,
      type?: string,
    },
    replied_message?: {
      message?: string | null,
      name?: string | null,
    },
  },
  isFromApplication: boolean | null
  applicationAgentName: string | null
}

let props = withDefaults(defineProps<Props>(), {
  isSeller: false,
  isLoader: false,
  date: null,
  is_forwarded: 0,
  assignee: null,
  reactions: [],
  isFromApplication: null,
  applicationAgentName: null,
  chatType: null,
  message: null,
  wa_error_message: null,
  status: null,
  object: null,
});
const dashboardStore = useDashboardStore()
const downloadProgress = ref(false)

const getFilename = (fileurl) => {
  if (fileurl) return fileurl.substring(fileurl.lastIndexOf('/') + 1)
}

const copyContact = () => {
  if (navigator.clipboard.writeText(props.object.contact.phone)) {
    message.success("Contact berhasil di salin")
  }
}

const importContact = () => {
  dashboardStore.sendImportContact([{
    name: props.object?.contact?.name,
    phone: props.object?.contact?.phone,
  }])
}
</script>